purpose
=======

these are two breakout boards for USB-C connectors, one for the plug, the other for the receptacle.
they allow to easily connect to the 24 pins, plus the shield, of USB-C connectors.
they are breadboard friendly, using 500 mil spacing between the A and B side.
like the cable itself, they signals pinout is symmetrical, allowing to flip the board (along the connector axis).
the form factor and pinout for the plug and receptacle breakout boards are identical, allowing to stack them up.

design choice
=============

to debug USB-C devices and cables I needed a way to access all 24 pins.
for easy access to the pins I wanted standard 2.54 mm/100 mil headers.
so it can also be used to design or test devices I want it to be breadboard friendly (at least 400 mil spacing between the columns).
to be able to tap signal or be man in the middle, I wanted them to be stackable (same form factor an pinout for plug and receptacle).

you can already find USB-C breakout boards on AliExpress, but they none fitted all aforementioned requirements.

note
----

for USB-C devices, not all 24 pins are required.
if you just want power, 4-signal (VCC, VBUS, CC, VCONN) 6-pin (2x GND, 2x VBUS, CC1, CC2) connectors are sufficient.
if you just want USB 2.0, 12-signal 16-pin connectors are the norm.

warning
-------

because they are stackable and boards for both connectors are available, they could be used to inter-connect cables or devices.
the differential signal traces are close together and length matched.
for the USB 2.0 data lines D+/D- this is fine.
but the USB 3.x SuperSpeed data lines SSTX+n/SSTX-n/SSRX+n/SSRX-n are not shielded and impedance controlled.
thus the signal integrity is not guaranteed.

parts
-----

I used USB-C plug and receptacle from LCSC (details are in the BOM).
they are readily available, cheap, and well documented.
but the footprint is fairly generic, and fits with the one specified in the USB Type-C standard.
thus compatible connectors from other manufacturer are available.

requirements
============

to be able to generate the outputs you need following software:
- rake: the central script taking care of generating the output files (Makefile is too cumbersome to parse files). following gems are required: open_uri_redirections nokogiri
- [QEDA](http://qeda.org/): to generate footprints for the parts
- [Lepton EDA](https://github.com/lepton-eda/lepton-eda): for the schematic capture
- [pcb-rnd](http://repo.hu/projects/pcb-rnd/): for the board layout
the output generation is automatized.

schematic
=========

library
-------

almost all of the symbols and footprints used in the schematic and board layout are defined in the [QEDA](http://qeda.org/) format and generated for the CAD software.
the `library` folder contains the QEDA parts definitions.

to install QEDA using NPM from the official repository:
~~~
sudo npm install -g qeda
~~~

to install QEDA from the sources:
~~~
git clone https://github.com/qeda/qeda
cd qeda
npm install
sudo npm install --global
~~~

to generate the parts:
~~~
rake library
~~~

this will use the parts definition (.yaml files) in the `library` to generate [gEDA gschem](http://wiki.geda-project.org/geda:gaf)/[Lepton EDA](https://github.com/lepton-eda/lepton-eda) symbols (.sym files) in the `geda/symbols` folder, and [coralEDA pcb-rnd](http://repo.hu/projects/pcb-rnd/) footprints (.lht files) in the `coraleda/subc` folder.

only the QEDA parts in subfolders within `library` come from the [QEDA library](https://doc.qeda.org/library/), but the files are included in this project for simplicity and archiving purposes.
all other parts are custom and written for this project.

schematic
---------

the `usb_cable_tester.sch` file is the schematic source file.
it has been drawn using [Lepton EDA](https://github.com/lepton-eda/lepton-eda).

it uses standard symbols, and the ones in the `geda/symbols/` folder.
only `bordered-A1.sym` and `title.sym` are hand drawn.
all other symbols are generated by QEDA as described above.

to export the netlist (in tEDAx format):
~~~
rake netlist
~~~

to export as pdf:
~~~
rake print
~~~

BOM
---

to export the bill of material (as CSV):
~~~
rake bom
~~~

board
=====

the `usb_cable_test.lht` file is the board layout source file.
it has been drawn using  [coralEDA pcb-rnd](http://repo.hu/projects/pcb-rnd/).

it uses the symbols from the `coraleda/subc/` folder.
all symbols are generated by QEDA as described above.

to export gerber files for PCB manufacturer (and photo preview + overview document):
~~~
rake fabrication
~~~

fabrication
===========

use boards with a thickness of 0.8 mm, so the plug can be mounted on the edge, and because the USB-C receptacle leads are only 1.3 mm long.
